@@ -103,9 +103,20 @@ class GlinkNode(Node):
 		try:
 			# Nifty little switcharoo from string to object.
 			self.blueprint = Blueprint.objects.get(name=self.blueprint)
-			glinks = Glink.objects.filter(blueprint=self.blueprint)
+			glinks = Glink.objects.filter(blueprint=self.blueprint, isActive=True)
 
 			if len(glinks) > 0:
+
+				for glink in glinks:
+					if glink.start_date == None:
+						glinks = glinks.exclude(pk=glink.pk)
+					elif glink.start_date.replace(tzinfo=None) > datetime.now():
+						glinks = glinks.exclude(pk=glink.pk)
+					else:
+						if glink.expiry_date != None:
+							if glink.expiry_date.replace(tzinfo=None) < datetime.now():
+								glinks = glinks.exclude(pk=glink.pk)
+
 				weight_list = generateWeightedListFromGlinks(glinks)
 
 				weight = weight_list[randint(0, len(weight_list)-1)]
@@ -139,7 +150,7 @@ class GlinkNode(Node):
 		return img_lead + img_url + on_click + glink_page + height + width + img_close
 		'''
 		if self.glink != None:
-			impressionTracking = ImpressionTracking(glink_id=self.glink, latitude=tracking_dict["Latitude"].strip(), 
+			impressionTracking = ImpressionTracking(glink_id=self.glink, ip=user_ip, latitude=tracking_dict["Latitude"].strip(), 
 				longitude=tracking_dict["Longitude"].strip(), country=tracking_dict["Country"].strip(), 
 				city=tracking_dict["City"].strip())
 			impressionTracking.save()
